@@ -1,5 +1,3 @@
-from __future__ import absolute_import, print_function
-
 from pprint import pprint
 
 import six
@@ -196,7 +194,7 @@ class PIPSatchel(Satchel):
         Called after a deployment to record any data necessary to detect changes
         for a future deployment.
         """
-        manifest = super(PIPSatchel, self).record_manifest()
+        manifest = super().record_manifest()
         manifest['all-requirements'] = self.get_combined_requirements()
         if self.verbose:
             pprint(manifest, indent=4)
